@@ -1,5 +1,5 @@
 # add shortcuts to the package's first level
 
 from . import datasets
-from .main import SpatialDM, read_spataildm, compute_pathway
+from .main import *
 from .version import __version__
